EventIdSet

Struct EventIdSet 

pub struct EventIdSet<E>(/* private fields */)
where
    E: Borrow<EventId>;
Available on crate feature state-res only.
A set of event IDs.

Implementations

Source

impl<E> EventIdSet<E>
where E: Borrow<EventId>,

pub fn new() -> EventIdSet<E>

Create an empty EventIdSet.

pub fn with_capacity(capacity: usize) -> EventIdSet<E>

Create an empty EventIdSet with the given capacity.

pub fn clear(&mut self)

Clears the set, removing all event IDs.

pub fn len(&self) -> usize

Returns the number of elements in the set.

pub fn is_empty(&self) -> bool

Returns true if the set contains no elements.

pub fn iter(&self) -> EventIdSetIter<'_, E>

Gets an iterator over the elements of the set.

Source

impl<E> EventIdSet<E>
where E: Borrow<EventId> + Eq + Hash,

pub fn contains(&self, event_id: &EventId) -> bool

Returns true if the set contains the specified event ID.

pub fn get(&self, event_id: &EventId) -> Option<&E>

Returns a reference to the event ID in the set, if any, that is equal to the given one.

pub fn insert(&mut self, event_id: E) -> bool

Adds an event ID to the set.

Returns whether the ID was newly inserted.

pub fn remove(&mut self, event_id: &EventId) -> bool

Removes an event ID from the set.

Returns whether the ID was present in the set.

pub fn take(&mut self, event_id: &EventId) -> Option<E>

Removes and returns the event ID in the set, if any, that is equal to the given one.

pub fn intersection<'a>( &'a self, other: &'a EventIdSet<E>, ) -> EventIdSetIntersection<'a, E>

Visits the values representing the intersection, i.e., the values that are both in self and other.