pub struct EventIdSet<E>(/* private fields */)
where
E: Borrow<EventId>;Available on crate feature
state-res only.Expand description
A set of event IDs.
Implementations
Sourceimpl<E> EventIdSet<E>
impl<E> EventIdSet<E>
Sourcepub fn new() -> EventIdSet<E>
pub fn new() -> EventIdSet<E>
Create an empty EventIdSet.
Sourcepub fn with_capacity(capacity: usize) -> EventIdSet<E>
pub fn with_capacity(capacity: usize) -> EventIdSet<E>
Create an empty EventIdSet with the given capacity.
Sourcepub fn iter(&self) -> EventIdSetIter<'_, E> ⓘ
pub fn iter(&self) -> EventIdSetIter<'_, E> ⓘ
Gets an iterator over the elements of the set.
Sourceimpl<E> EventIdSet<E>
impl<E> EventIdSet<E>
Sourcepub fn contains(&self, event_id: &EventId) -> bool
pub fn contains(&self, event_id: &EventId) -> bool
Returns true if the set contains the specified event ID.
Sourcepub fn get(&self, event_id: &EventId) -> Option<&E>
pub fn get(&self, event_id: &EventId) -> Option<&E>
Returns a reference to the event ID in the set, if any, that is equal to the given one.
Sourcepub fn insert(&mut self, event_id: E) -> bool
pub fn insert(&mut self, event_id: E) -> bool
Adds an event ID to the set.
Returns whether the ID was newly inserted.
Sourcepub fn remove(&mut self, event_id: &EventId) -> bool
pub fn remove(&mut self, event_id: &EventId) -> bool
Removes an event ID from the set.
Returns whether the ID was present in the set.
Sourcepub fn take(&mut self, event_id: &EventId) -> Option<E>
pub fn take(&mut self, event_id: &EventId) -> Option<E>
Removes and returns the event ID in the set, if any, that is equal to the given one.
Sourcepub fn intersection<'a>(
&'a self,
other: &'a EventIdSet<E>,
) -> EventIdSetIntersection<'a, E> ⓘ
pub fn intersection<'a>( &'a self, other: &'a EventIdSet<E>, ) -> EventIdSetIntersection<'a, E> ⓘ
Visits the values representing the intersection, i.e., the values that are both in self and other.